==> pyloadl-0.0.1b1.tar.bz2: pyloadl-0.0.1b1/examples/class.py <==
from pyloadl import *
from string import join
from sys import exit

"""

  Display information about the current LoadLeveler classes 
  similar to the llclass -l command

"""

query = ll_query(CLASSES)
if not query:
  print "ll_query(): error in query\n"
  exit(-1)

b = ll_set_request(query, QUERY_ALL, [""], ALL_DATA)
if b != 0:
  print "ll_set_request(): error %d\n" % b
  exit(-1)

classes, number, error = ll_get_objs(query, LL_CM, "")
if error != 0:
  print "ll_get_objs(): error %d\n" % error
  exit(-1)

while PyCObjValid(classes):

  class_name = ll_get_data(classes,LL_ClassName)
  class_prio = ll_get_data(classes,LL_ClassPriority)
  class_exc_users = ll_get_data(classes,LL_ClassExcludeUsers)
  class_inc_users = ll_get_data(classes,LL_ClassIncludeUsers)
  class_exc_group = ll_get_data(classes,LL_ClassExcludeGroups)
  class_inc_group = ll_get_data(classes,LL_ClassIncludeGroups)
  class_admin = ll_get_data(classes,LL_ClassAdmin)
  class_nqs_class = ll_get_data(classes,LL_ClassNqsClass)
  class_nqs_submit = ll_get_data(classes,LL_ClassNqsSubmit)
  class_nqs_query = ll_get_data(classes,LL_ClassNqsQuery)
  class_max_procs = ll_get_data(classes,LL_ClassMaxProcessors)
  class_max_jobs = ll_get_data(classes,LL_ClassMaxJobs)

  class_res_str = ""
  class_res_req = ll_get_data(classes,LL_ClassGetFirstResourceRequirement)
  while PyCObjValid(class_res_req):

    name = ll_get_data(class_res_req, LL_ResourceRequirementName)
    init_val = ll_get_data(class_res_req, LL_ResourceRequirementValue)
    class_res_str = name + "(" + str(init_val) + ")"

    class_res_req = ll_get_data(classes, LL_ClassGetNextResourceRequirement)

    class_comment = ll_get_data(classes,LL_ClassComment)
    class_ckpt_dir = ll_get_data(classes,LL_ClassCkptDir)
    class_ckpt_hlimit = ll_get_data(classes,LL_ClassCkptTimeHardLimit)
    class_ckpt_slimit = ll_get_data(classes,LL_ClassCkptTimeSoftLimit)
    class_wcl_hlimit = ll_get_data(classes,LL_ClassWallClockLimitHard)
    class_wcl_slimit = ll_get_data(classes,LL_ClassWallClockLimitSoft)
    class_jcpu_hlimit = ll_get_data(classes,LL_ClassCpuStepLimitHard)
    class_jcpu_slimit = ll_get_data(classes,LL_ClassCpuStepLimitSoft)
    class_cpu_hlimit = ll_get_data(classes,LL_ClassCpuLimitHard)
    class_cpu_slimit = ll_get_data(classes,LL_ClassCpuLimitSoft)
    class_data_hlimit = ll_get_data(classes,LL_ClassDataLimitHard)
    class_data_slimit = ll_get_data(classes,LL_ClassDataLimitSoft)
    class_core_hlimit = ll_get_data(classes,LL_ClassCoreLimitHard)
    class_core_slimit = ll_get_data(classes,LL_ClassCoreLimitSoft)
    class_file_hlimit = ll_get_data(classes,LL_ClassFileLimitHard)
    class_file_slimit = ll_get_data(classes,LL_ClassFileLimitSoft)
    class_stack_hlimit = ll_get_data(classes,LL_ClassStackLimitHard)
    class_stack_slimit = ll_get_data(classes,LL_ClassStackLimitSoft)
    class_rss_hlimit = ll_get_data(classes,LL_ClassRssLimitHard)
    class_rss_slimit = ll_get_data(classes,LL_ClassRssLimitSoft)

    class_nice = ll_get_data(classes,LL_ClassNice)
    class_free_slots = ll_get_data(classes,LL_ClassFreeSlots)
    class_max_slots = ll_get_data(classes,LL_ClassMaximumSlots)
    class_exec_factor = ll_get_data(classes,LL_ClassExecutionFactor)
    class_max_total_tasks = ll_get_data(classes,LL_ClassMaxTotalTasks)
    class_max_proto_inst = ll_get_data(classes,LL_ClassMaxProtocolInstances)
    class_preempt_class = ll_get_data(classes,LL_ClassPreemptClass)
    class_start_class = ll_get_data(classes,LL_ClassStartClass)

    class_constraints = ll_get_data(classes,LL_ClassConstraints);

    print "=============== Class class_name ==============="
    print "                Name: %s" % class_name
    print "            Priority: %s" % class_prio
    print "       Exclude_Users: %s" % join(class_exc_users,',')
    print "       Include_Users: %s" % join(class_inc_users,',')
    print "      Exclude_Groups: %s" % join(class_exc_group,',')
    print "      Include_Groups: %s" % join(class_inc_group,',')
    print "               Admin: %s" % join(class_admin,',')
    print "           NQS_class: %s" % bool(class_nqs_class)
    print "          NQS_submit: %s" % class_nqs_submit
    print "           NQS_query: %s" % join(class_nqs_query,',')
    print "      Max_processors: %d" % class_max_procs
    print "             Maxjobs: %d" % class_max_jobs
    print "Resource_requirement: %s" % class_res_str
    print "       Class_comment: %s" % class_comment
    print "      Class_ckpt_dir: %s" % class_ckpt_dir
    print "          Ckpt_limit: %d, %d" % (class_ckpt_hlimit, class_ckpt_slimit)
    print "    Wall_clock_limit: %d, %d" % (class_wcl_hlimit, class_wcl_slimit)
    print "       Job_cpu_limit: %d, %d" % (class_jcpu_hlimit, class_jcpu_slimit)
    print "           Cpu_limit: %d, %d" % (class_cpu_hlimit, class_cpu_slimit)
    print "          Data_limit: %d, %d" % (class_data_hlimit, class_data_slimit)
    print "          Core_limit: %d, %d" % (class_core_hlimit, class_core_slimit)
    print "          File_limit: %d, %d" % (class_file_hlimit, class_file_slimit)
    print "         Stack_limit: %d, %d" % (class_stack_hlimit, class_stack_slimit)
    print "           Rss_limit: %d, %d" % (class_rss_hlimit, class_rss_slimit)
    print "                Nice: %d" % class_nice
    print "          Free_slots: %d" % class_free_slots
    print "       Maximum_slots: %d" % class_max_slots
    print "    Execution_factor: %d" % class_exec_factor
    print "     Max_total_tasks: %d" % class_max_total_tasks
    print " Max_proto_instances: %s" % class_max_proto_inst
    print "       Preempt_class: %s" % class_preempt_class
    print "         Start_class: %s" % class_start_class

    if class_constraints:
      print "-------------------------------------------------------\n"

    if class_constraints & 1:
      print "\"Maximum Slots\" value of class \"class_name\" is constrained by the MAX_STARTERS limit(s)\n"

    if class_constraints & 2:
      print "\"Free Slots\" value of class \"class_name\" is constrained by the MAX_STARTERS limit(s).\n"

    if class_constraints & 4:
      print "\"Free Slots\" value of class \"class_names\" is constrained by the MAXJOBS limit(s).\n"

  classes = ll_next_obj(query)

==> pyloadl-0.0.2.tar.bz2: pyloadl-0.0.2/examples/class.py <==
from pyloadl import *
from string import join
from sys import exit

"""

  Display information about the current LoadLeveler classes 
  similar to the llclass -l command

"""

query = ll_query(CLASSES)
if not PyCObjValid(query):
  print "ll_query(): returns a NULL\n"
  exit(-1)

b = ll_set_request(query, QUERY_ALL, [""], ALL_DATA)
if b != 0:
  print "ll_set_request(): error %d\n" % b
  exit(-1)

classes, number, error = ll_get_objs(query, LL_CM, "")
if error != 0:
  print "ll_get_objs(): error %d\n" % error
  exit(-1)

while PyCObjValid(classes):

  class_name = ll_get_data(classes,LL_ClassName)
  class_prio = ll_get_data(classes,LL_ClassPriority)
  class_exc_users = ll_get_data(classes,LL_ClassExcludeUsers)
  class_inc_users = ll_get_data(classes,LL_ClassIncludeUsers)
  class_exc_group = ll_get_data(classes,LL_ClassExcludeGroups)
  class_inc_group = ll_get_data(classes,LL_ClassIncludeGroups)
  class_admin = ll_get_data(classes,LL_ClassAdmin)
  class_nqs_class = ll_get_data(classes,LL_ClassNqsClass)
  class_nqs_submit = ll_get_data(classes,LL_ClassNqsSubmit)
  class_nqs_query = ll_get_data(classes,LL_ClassNqsQuery)
  class_max_procs = ll_get_data(classes,LL_ClassMaxProcessors)
  class_max_jobs = ll_get_data(classes,LL_ClassMaxJobs)

  class_res_str = ""
  class_res_req = ll_get_data(classes,LL_ClassGetFirstResourceRequirement)
  while PyCObjValid(class_res_req):

    name = ll_get_data(class_res_req, LL_ResourceRequirementName)
    init_val = ll_get_data(class_res_req, LL_ResourceRequirementValue)
    class_res_str = name + "(" + str(init_val) + ")"

    class_res_req = ll_get_data(classes, LL_ClassGetNextResourceRequirement)

    class_comment = ll_get_data(classes,LL_ClassComment)
    class_ckpt_dir = ll_get_data(classes,LL_ClassCkptDir)
    class_ckpt_hlimit = ll_get_data(classes,LL_ClassCkptTimeHardLimit)
    class_ckpt_slimit = ll_get_data(classes,LL_ClassCkptTimeSoftLimit)
    class_wcl_hlimit = ll_get_data(classes,LL_ClassWallClockLimitHard)
    class_wcl_slimit = ll_get_data(classes,LL_ClassWallClockLimitSoft)
    class_jcpu_hlimit = ll_get_data(classes,LL_ClassCpuStepLimitHard)
    class_jcpu_slimit = ll_get_data(classes,LL_ClassCpuStepLimitSoft)
    class_cpu_hlimit = ll_get_data(classes,LL_ClassCpuLimitHard)
    class_cpu_slimit = ll_get_data(classes,LL_ClassCpuLimitSoft)
    class_data_hlimit = ll_get_data(classes,LL_ClassDataLimitHard)
    class_data_slimit = ll_get_data(classes,LL_ClassDataLimitSoft)
    class_core_hlimit = ll_get_data(classes,LL_ClassCoreLimitHard)
    class_core_slimit = ll_get_data(classes,LL_ClassCoreLimitSoft)
    class_file_hlimit = ll_get_data(classes,LL_ClassFileLimitHard)
    class_file_slimit = ll_get_data(classes,LL_ClassFileLimitSoft)
    class_stack_hlimit = ll_get_data(classes,LL_ClassStackLimitHard)
    class_stack_slimit = ll_get_data(classes,LL_ClassStackLimitSoft)
    class_rss_hlimit = ll_get_data(classes,LL_ClassRssLimitHard)
    class_rss_slimit = ll_get_data(classes,LL_ClassRssLimitSoft)

    class_nice = ll_get_data(classes,LL_ClassNice)
    class_free_slots = ll_get_data(classes,LL_ClassFreeSlots)
    class_max_slots = ll_get_data(classes,LL_ClassMaximumSlots)
    class_exec_factor = ll_get_data(classes,LL_ClassExecutionFactor)
    class_max_total_tasks = ll_get_data(classes,LL_ClassMaxTotalTasks)
    class_max_proto_inst = ll_get_data(classes,LL_ClassMaxProtocolInstances)
    class_preempt_class = ll_get_data(classes,LL_ClassPreemptClass)
    class_start_class = ll_get_data(classes,LL_ClassStartClass)

    class_constraints = ll_get_data(classes,LL_ClassConstraints);

    print "=============== Class class_name ==============="
    print "                Name: %s" % class_name
    print "            Priority: %s" % class_prio
    print "       Exclude_Users: %s" % join(class_exc_users,',')
    print "       Include_Users: %s" % join(class_inc_users,',')
    print "      Exclude_Groups: %s" % join(class_exc_group,',')
    print "      Include_Groups: %s" % join(class_inc_group,',')
    print "               Admin: %s" % join(class_admin,',')
    print "           NQS_class: %s" % bool(class_nqs_class)
    print "          NQS_submit: %s" % class_nqs_submit
    print "           NQS_query: %s" % join(class_nqs_query,',')
    print "      Max_processors: %d" % class_max_procs
    print "             Maxjobs: %d" % class_max_jobs
    print "Resource_requirement: %s" % class_res_str
    print "       Class_comment: %s" % class_comment
    print "      Class_ckpt_dir: %s" % class_ckpt_dir
    print "          Ckpt_limit: %d, %d" % (class_ckpt_hlimit, class_ckpt_slimit)
    print "    Wall_clock_limit: %d, %d" % (class_wcl_hlimit, class_wcl_slimit)
    print "       Job_cpu_limit: %d, %d" % (class_jcpu_hlimit, class_jcpu_slimit)
    print "           Cpu_limit: %d, %d" % (class_cpu_hlimit, class_cpu_slimit)
    print "          Data_limit: %d, %d" % (class_data_hlimit, class_data_slimit)
    print "          Core_limit: %d, %d" % (class_core_hlimit, class_core_slimit)
    print "          File_limit: %d, %d" % (class_file_hlimit, class_file_slimit)
    print "         Stack_limit: %d, %d" % (class_stack_hlimit, class_stack_slimit)
    print "           Rss_limit: %d, %d" % (class_rss_hlimit, class_rss_slimit)
    print "                Nice: %d" % class_nice
    print "          Free_slots: %d" % class_free_slots
    print "       Maximum_slots: %d" % class_max_slots
    print "    Execution_factor: %d" % class_exec_factor
    print "     Max_total_tasks: %d" % class_max_total_tasks
    print " Max_proto_instances: %s" % class_max_proto_inst
    print "       Preempt_class: %s" % class_preempt_class
    print "         Start_class: %s" % class_start_class

    if class_constraints:
      print "-------------------------------------------------------\n"

    if class_constraints & 1:
      print "\"Maximum Slots\" value of class \"class_name\" is constrained by the MAX_STARTERS limit(s)\n"

    if class_constraints & 2:
      print "\"Free Slots\" value of class \"class_name\" is constrained by the MAX_STARTERS limit(s).\n"

    if class_constraints & 4:
      print "\"Free Slots\" value of class \"class_names\" is constrained by the MAXJOBS limit(s).\n"

  classes = ll_next_obj(query)
